@@ -20,10 +20,10 @@ sys.path.insert(0, os.path.dirname(__file__))
 sys.path.insert(0, os.path.join(os.path.dirname(__file__),'..','..','teaspoon','ML'))
 sys.path.insert(0, os.path.join(os.path.dirname(__file__),'teaspoon','ML'))
 
-import feature_functions as fF
-import Base
+import teaspoon.ML.feature_functions as fF
+import teaspoon.ML.Base as Base
 
-sys.path.insert(0, os.path.join(os.path.dirname(__file__),'libsvm-3.23','python'))
+sys.path.insert(0, os.path.join(os.path.dirname(__file__),'libsvm','python'))
 from svmutil import *
 
 def CL_PL(PL,params):
